# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2016-11-17 12:15
from __future__ import unicode_literals

from django.db import migrations
import wagtail.wagtailcore.blocks
import wagtail.wagtailcore.fields
import wagtail.wagtaildocs.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0004_auto_20161103_1446'),
    ]

    operations = [
        migrations.AlterField(
            model_name='griditem',
            name='buttons',
            field=wagtail.wagtailcore.fields.StreamField((('button_section', wagtail.wagtailcore.blocks.StructBlock((('action_items', wagtail.wagtailcore.blocks.StreamBlock((('document_button', wagtail.wagtailcore.blocks.StructBlock((('label', wagtail.wagtailcore.blocks.TextBlock(required=True)), ('document', wagtail.wagtaildocs.blocks.DocumentChooserBlock(required=True))), icon='fa-file')), ('url_button', wagtail.wagtailcore.blocks.StructBlock((('label', wagtail.wagtailcore.blocks.TextBlock(required=True)), ('url', wagtail.wagtailcore.blocks.TextBlock(required=True))), icon='fa-link')), ('placeholder', wagtail.wagtailcore.blocks.StructBlock((), icon='fa-square-o'))), help_text='A button or URL within a button section.')),))),), null=True),
        ),
    ]
