# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-17 14:04
from __future__ import unicode_literals

from django.db import migrations
import modelcluster.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0006_auto_20170217_1354'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='gridcategory',
            options={'verbose_name_plural': 'grid categories'},
        ),
        migrations.AddField(
            model_name='griditem',
            name='categories',
            field=modelcluster.fields.ParentalManyToManyField(blank=True, to='wagtailgridder.GridCategory'),
        ),
    ]
