# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-14 13:52
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0002_griditem_landing_page_text'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='griditem',
            name='target_url',
        ),
    ]
