# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-17 13:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailgridder', '0005_auto_20161117_0715'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='gridcategorygriditem',
            name='category',
        ),
        migrations.RemoveField(
            model_name='gridcategorygriditem',
            name='page',
        ),
        migrations.RemoveField(
            model_name='griditem',
            name='landing_page_image',
        ),
        migrations.DeleteModel(
            name='GridCategoryGridItem',
        ),
    ]
